==> okareo-0.0.21-py3-none-any.whl: okareo_api_client/api/default/add_test_data_point_v0_test_data_point_post.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.test_data_point_payload import TestDataPointPayload
from ...models.test_data_point_response import TestDataPointResponse
from ...types import Response


def _get_kwargs(
    *,
    json_body: TestDataPointPayload,
    api_key: str,
) -> Dict[str, Any]:
    headers = {}
    headers["api-key"] = api_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/v0/test_data_point",
        "json": json_json_body,
        "headers": headers,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, TestDataPointResponse]]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = TestDataPointResponse.from_dict(response.json())

        return response_201
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, TestDataPointResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Response[Union[HTTPValidationError, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, TestDataPointResponse]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Optional[Union[HTTPValidationError, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, TestDataPointResponse]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        api_key=api_key,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Response[Union[HTTPValidationError, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, TestDataPointResponse]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Optional[Union[HTTPValidationError, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, TestDataPointResponse]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            api_key=api_key,
        )
    ).parsed

==> okareo-0.0.54-py3-none-any.whl: okareo_api_client/api/default/add_test_data_point_v0_test_data_point_post.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error_response import ErrorResponse
from ...models.test_data_point_payload import TestDataPointPayload
from ...models.test_data_point_response import TestDataPointResponse
from ...types import Response


def _get_kwargs(
    *,
    json_body: TestDataPointPayload,
    api_key: str,
) -> Dict[str, Any]:
    headers = {}
    headers["api-key"] = api_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/v0/test_data_point",
        "json": json_json_body,
        "headers": headers,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ErrorResponse, TestDataPointResponse]]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = TestDataPointResponse.from_dict(response.json())

        return response_201
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ErrorResponse.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = ErrorResponse.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ErrorResponse, TestDataPointResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Response[Union[ErrorResponse, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, TestDataPointResponse]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Optional[Union[ErrorResponse, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, TestDataPointResponse]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        api_key=api_key,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Response[Union[ErrorResponse, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, TestDataPointResponse]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestDataPointPayload,
    api_key: str,
) -> Optional[Union[ErrorResponse, TestDataPointResponse]]:
    """Add Test Data Point

     Add a test run metric

    Returns:
        The persisted test run metric item

    Args:
        api_key (str):
        json_body (TestDataPointPayload):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, TestDataPointResponse]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            api_key=api_key,
        )
    ).parsed
